Data structures used by operation inputs/outputs.
Modules
Structs
- Customer
Profiles Integration Config Specifies the configuration for integrating with Customer Profiles. This configuration enables Entity Resolution to send matched output directly to Customer Profiles instead of Amazon S3, creating a unified customer view by automatically updating customer profiles based on match clusters.
- Delete
Unique IdError The error information provided when the delete unique ID operation doesn't complete.
- Deleted
Unique Id The deleted unique ID.
- Error
Details An object containing an error message, if there was an error.
- Failed
Record The record that didn't generate a Match ID.
- IdMapping
Incremental RunConfig Incremental run configuration for an ID mapping workflow.
- IdMapping
JobMetrics An object that contains metrics about an ID mapping job, including counts of input records, processed records, and mapped records between source and target identifiers.
- IdMapping
JobOutput Source An object containing
KMSArn,outputS3Path, androleARN.- IdMapping
Rule Based Properties An object that defines the list of matching rules to run in an ID mapping workflow.
- IdMapping
Techniques An object which defines the ID mapping technique and any additional configurations.
- IdMapping
Workflow Input Source An object containing
inputSourceARN,schemaName, andtype.- IdMapping
Workflow Output Source The output source for the ID mapping workflow.
- IdMapping
Workflow Summary A list of
IdMappingWorkflowSummaryobjects, each of which contain the fieldsWorkflowName,WorkflowArn,CreatedAt, andUpdatedAt.- IdNamespace
IdMapping Workflow Metadata The settings for the ID namespace for the ID mapping workflow job.
- IdNamespace
IdMapping Workflow Properties An object containing
idMappingType,providerProperties, andruleBasedProperties.- IdNamespace
Input Source An object containing
inputSourceARNandschemaName.- IdNamespace
Summary A summary of ID namespaces.
- Incremental
RunConfig Optional. An object that defines the incremental run type. This object contains only the
incrementalRunTypefield, which appears as "Automatic" in the console.For workflows where
resolutionTypeisPROVIDER, incremental processing is not supported.- Input
Source An object containing
inputSourceARN,schemaName, andapplyNormalization.- Intermediate
Source Configuration The Amazon S3 location that temporarily stores your data while it processes. Your information won't be saved permanently.
- JobMetrics
An object containing
inputRecords,totalRecordsProcessed,matchIDs, andrecordsNotProcessed.- JobOutput
Source An object containing
KMSArn,outputS3Path, androleArn.- JobSummary
An object containing the
jobId,status,startTime, andendTimeof a job.- Match
Group The match group.
- Matched
Record The matched record.
- Matching
Config An object that contains configuration settings for the matching process in a rule-based matching workflow.
- Matching
Workflow Summary A list of
MatchingWorkflowSummaryobjects, each of which contain the fieldsworkflowName,workflowArn,resolutionType,createdAt,updatedAt.- Namespace
Provider Properties An object containing
providerConfigurationandproviderServiceArn.- Namespace
Rule Based Properties The rule-based properties of an ID namespace. These properties define how the ID namespace can be used in an ID mapping workflow.
- Output
Attribute A list of
OutputAttributeobjects, each of which have the fieldsNameandHashed. Each of these objects selects a column to be included in the output table, and whether the values of the column should be hashed.- Output
Source A list of
OutputAttributeobjects, each of which have the fieldsNameandHashed. Each of these objects selects a column to be included in the output table, and whether the values of the column should be hashed.- Provider
Component Schema The input schema supported by provider service.
- Provider
IdName Space Configuration The provider configuration required for different ID namespace types.
- Provider
Intermediate Data Access Configuration The required configuration fields to give intermediate access to a provider service.
- Provider
Marketplace Configuration The identifiers of the provider service, from Data Exchange.
- Provider
Properties An object containing the
providerServiceARN,intermediateSourceConfiguration, andproviderConfiguration.- Provider
Schema Attribute The provider schema attribute.
- Provider
Service Summary A list of
ProviderServiceobjects, each of which contain the fieldsproviderName,providerServiceArn,providerServiceName, andproviderServiceType.- Record
The record.
- Resolution
Techniques An object which defines the
resolutionTypeand theruleBasedProperties.- Rule
An object containing the
ruleNameandmatchingKeys.- Rule
Based Properties An object which defines the list of matching rules to run in a matching workflow.
- Rule
Condition An object that defines the
ruleConditionand theruleNameto use in a matching workflow.- Rule
Condition Properties The properties of a rule condition that provides the ability to use more complex syntax.
- Schema
Input Attribute A configuration object for defining input data fields in Entity Resolution. The
SchemaInputAttributespecifies how individual fields in your input data should be processed and matched.- Schema
Mapping Summary An object containing
schemaName,schemaArn,createdAt,updatedAt, andhasWorkflows.
Enums
- Attribute
Matching Model - When writing a match expression against
AttributeMatchingModel, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature. - Delete
Unique IdError Type - When writing a match expression against
DeleteUniqueIdErrorType, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature. - Delete
Unique IdStatus - When writing a match expression against
DeleteUniqueIdStatus, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature. - IdMapping
Incremental RunType - When writing a match expression against
IdMappingIncrementalRunType, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature. - IdMapping
Type - When writing a match expression against
IdMappingType, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature. - IdMapping
Workflow Rule Definition Type - When writing a match expression against
IdMappingWorkflowRuleDefinitionType, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature. - IdNamespace
Type - When writing a match expression against
IdNamespaceType, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature. - Incremental
RunType - When writing a match expression against
IncrementalRunType, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature. - JobStatus
- When writing a match expression against
JobStatus, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature. - JobType
- When writing a match expression against
JobType, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature. - Match
Purpose - When writing a match expression against
MatchPurpose, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature. - Processing
Type - When writing a match expression against
ProcessingType, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature. - Provider
Endpoint Configuration The required configuration fields to use with the provider service.
- Record
Matching Model - When writing a match expression against
RecordMatchingModel, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature. - Resolution
Type - When writing a match expression against
ResolutionType, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature. - Schema
Attribute Type - When writing a match expression against
SchemaAttributeType, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature. - Service
Type - When writing a match expression against
ServiceType, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature. - Statement
Effect - When writing a match expression against
StatementEffect, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature.