#[non_exhaustive]pub struct MatchingConfig {
pub enable_transitive_matching: Option<bool>,
}Expand description
An object that contains configuration settings for the matching process in a rule-based matching workflow.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.enable_transitive_matching: Option<bool>Enables transitive matching for the rule-based matching workflow. When enabled, records that match through different rules are grouped together into the same match group.
Implementations
Sourceimpl MatchingConfig
impl MatchingConfig
Sourcepub fn enable_transitive_matching(&self) -> Option<bool>
pub fn enable_transitive_matching(&self) -> Option<bool>
Enables transitive matching for the rule-based matching workflow. When enabled, records that match through different rules are grouped together into the same match group.
Sourceimpl MatchingConfig
impl MatchingConfig
Sourcepub fn builder() -> MatchingConfigBuilder
pub fn builder() -> MatchingConfigBuilder
Creates a new builder-style object to manufacture MatchingConfig.